# DirichletMagmaMix

[![Documentation Status](https://readthedocs.org/projects/dirichletmagmamix/badge/?version=latest)](https://dirichletmagmamix.readthedocs.io/en/latest/?badge=latest) [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/simonwmatthews/DirichletMagmaMix/HEAD?labpath=tutorials%2Ftutorial1.ipynb) [![DOI](https://zenodo.org/badge/402828732.svg)](https://zenodo.org/badge/latestdoi/402828732) [![flake8](https://github.com/simonwmatthews/DirichletMagmaMix/actions/workflows/flake8.yml/badge.svg)](https://github.com/simonwmatthews/DirichletMagmaMix/actions/workflows/flake8.yml)

## Introduction

A python module for modelling partial melt aggregation using the Dirichlet distribution, as described by Rudge et al. (2013).

## Documentation

Complete documentation is provided at [dirichletmagmamix.readthedocs.io](https://dirichletmagmamix.readthedocs.io)

## Installation

DirichletMagmaMix will soon be available on pip, and will be installed using `pip install DirichletMagmaMix`.

## Run DirichletMagmaMix in the cloud

The library may be used in the cloud on myBinder, and is probably the best way of getting started:
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/simonwmatthews/DirichletMagmaMix/HEAD?labpath=tutorials%2Ftutorial1.ipynb)

## Citing the code

A manuscript will be coming soon. In the meantime, please cite the latest version of the repository on zenodo:
[![DOI](https://zenodo.org/badge/402828732.svg)](https://zenodo.org/badge/latestdoi/402828732)

## Support

If you encounter any problems or have any suggestions while using DirichletMagmaMix you can raise
issues on this github page. Alternatively, feel free to contact me at simonm@hi.is.
